@@ -23,12 +23,15 @@ import shutil
 from calculate.core.client.cert_func import new_key_req
 from calculate.core.client.function import get_ip_mac_type
 from calculate.core.datavars import DataVarsCore
-from calculate.lib.utils.files import makeDirectory, pathJoin
+from calculate.lib.utils.files import (makeDirectory, pathJoin, readFile,
+                                       writeFile, isMount)
+from calculate.core.server.admin import Admins
 import os
 import hashlib
 import pwd
 import socket
 import sys
+import re
 
 _ = lambda x: x
 from calculate.lib.cl_lang import setLocalTranslate
@@ -92,7 +95,7 @@ def check(cert, key):
     sys.exit(error_flag)
 
 
-def init(cert, key, cert_path, data_path, certbase, args, port, user_name):
+def init(cert, key, cert_path, data_path, certbase, args, port):
     if args.remove_certificates:
         key_force(cert_path, data_path)
 
@@ -105,11 +108,36 @@ def init(cert, key, cert_path, data_path, certbase, args, port, user_name):
         new_serv_cert = True
     else:
         print _('Server certificate now exists.')
-    if new_serv_cert or not check_client_cert(user_name):
+
+    os.chmod(data_path, 0700)
+
+def force_user_cert(server_cert, cert_path, data_path, cert_base, user_name,
+                    dv=None):
+    def is_crypthome_notmount(dv, username):
+        dv.Set('ur_login', user_name, force=True)
+        homedir = dv.Get('ur_home_path')
+        if (dv.GetBool('ur_home_crypt_set') and
+            '.Private' not in isMount(homedir)):
+            return True
+        return False
+        
+    if not check_client_cert(user_name, server_cert=server_cert):
         print _('Generating the client certificate')
-        create_client_cert(cert, cert_path, data_path, certbase, user_name)
     else:
-        print _('Client certificate now exists.')
+        print _('Regenerating the client certificate')
+    group = "all"
+    if dv:
+        admins = Admins(dv)
+        if user_name not in admins:
+            admins[user_name] = group
+            admins.save()
+        group = admins[user_name]
+        if is_crypthome_notmount(dv, user_name):
+            print _("User profile is encrypted. Please perform user login for "
+                    "complete of certificate generation")
+            return
+    create_client_cert(server_cert, cert_path, data_path, cert_base,
+                       user_name, group)
 
 
 def check_serv_cert(cert_path):
@@ -119,9 +147,12 @@ def check_serv_cert(cert_path):
     return False
 
 
-def check_client_cert(user_name):
+def check_client_cert(user_name, server_cert=None):
     client_cert_path = check_user_path(user_name)
-    server_host_name = socket.getfqdn()
+    if server_cert:
+        server_host_name = get_certificate_dn(server_cert)
+    else:
+        server_host_name = socket.getfqdn()
     crt_fn = os.path.join(client_cert_path, server_host_name + '.crt')
     key_fn = os.path.join(client_cert_path, server_host_name + '.key')
     if os.path.isfile(crt_fn) and os.path.isfile(key_fn):
@@ -147,15 +178,17 @@ def create_server_cert(cert, key, cert_path, args, port):
                                       auto=True)
 
 
-def create_client_cert(server_cert, cert_path, data_path, certbase, user_name):
+def create_client_cert(server_cert, cert_path, data_path, certbase, user_name,
+                       group="all"):
     client_cert_path = check_user_path(user_name)
     if not client_cert_path:
         print _('no path to the client certificate')
         return 1
     req_id = create_request(server_cert, cert_path, data_path, certbase,
                             client_cert_path, user_name)
-    sign_certificate(req_id, cert_path, data_path)
-    get_certificate(cert_path, data_path, certbase, client_cert_path, user_name)
+    sign_certificate(req_id, cert_path, data_path, group)
+    get_certificate(cert_path, data_path, certbase, client_cert_path, user_name,
+        server_cert=server_cert)
 
 
 def check_user_path(user_name):
@@ -192,7 +225,7 @@ def check_user_path(user_name):
 
 def create_request(server_cert, cert_path, data_path, certbase,
                    client_cert_path, user_name):
-    server_host_name = socket.getfqdn()
+    server_host_name = get_certificate_dn(server_cert)
 
     key = os.path.join(client_cert_path, server_host_name + '.key')
 
@@ -224,12 +257,48 @@ def create_request(server_cert, cert_path, data_path, certbase,
     return req_id
 
 
-def sign_certificate(req_id, cert_path, data_path):
-    cert_cmd.sing_req_by_server(req_id, cert_path, data_path, auto=True)
+def sign_certificate(req_id, cert_path, data_path, group="all"):
+    cert_cmd.sing_req_by_server(req_id, cert_path, data_path, auto=True,
+                                group_name=group)
+
+
+def get_certificate_dn(cert_file):
+    cert_data = readFile(cert_file)
+    if cert_data:
+        import OpenSSL
+        certobj = OpenSSL.crypto.load_certificate(
+            OpenSSL.SSL.FILETYPE_PEM, cert_data)
+        cert_info = dict(certobj.get_subject().get_components())
+        return cert_info["CN"]
+    return "localhost"
+
+
+def clear_localuser_certificates(certbase):
+    """
+    Удалить все пользовательские сертификаты, создаваемые для локальных
+    пользователей
+    """
+    certdata = readFile(certbase, grab=True)
+    certdn = os.path.dirname(certbase)
+    # оставляем только сертификаты, которые не содержат отметки
+    # для какого локального пользователя они созданы
+    writedata = "\n".join(x[0] for x in re.findall("^((\S+\s+){6}\S+)\s*$",
+                          certdata, flags=re.M))
+    with writeFile(certbase) as f:
+        f.write("%s\n"%writedata)
+
+    # удаляем физически сертификаты, созданные для локальных пользователей
+    for localcert in re.finditer("^(\S+)\s+(\S+\s+){6}\S+\s*$",
+                                 certdata, flags=re.M):
+        cert_fn = "%s/%s.crt"%(certdn, localcert.group(1))
+        try:
+            os.unlink(cert_fn)
+        except OSError:
+            print _("Failed to remove local client certificate") % cert_fn
 
 
 def get_certificate(cert_path, data_path, certbase, client_cert_path,
-                    user_name):
+                    user_name, server_cert=None):
     req_id_file = os.path.join(client_cert_path, 'req_id')
     if not os.path.exists(req_id_file):
         print _("request not sent or file %s deleted") % req_id_file
@@ -238,7 +307,10 @@ def get_certificate(cert_path, data_path, certbase, client_cert_path,
     req_id = fc.read()
     fc.close()
 
-    server_host_name = socket.getfqdn()
+    if server_cert:
+        server_host_name = get_certificate_dn(server_cert)
+    else:
+        server_host_name = socket.getfqdn()
 
     req_file = os.path.join(client_cert_path, server_host_name + '.csr')
     if not os.path.exists(req_file):
@@ -250,7 +322,8 @@ def get_certificate(cert_path, data_path, certbase, client_cert_path,
     md5sum = md5.hexdigest()
 
     result = post_request.serv_get_client_cert(
-        req_id, md5sum, data_path, certbase, cert_path)
+        req_id, md5sum, data_path, certbase, cert_path,
+        localuser=user_name)
 
     cert = result[0]
     if len(result) > 1:
