@@ -310,8 +310,9 @@ def create_path(data_path, certbase, rights, group_rights, local_data_path):
         fr.close()
 
     if not os.path.isfile(group_rights):
-        group_rights_text = '# example of content:\n' + \
-                            '#manager pid_info,list_pid,cl_template,install\n'
+        group_rights_text = ('# example of content:\n'
+                             '#manager pid_info,list_pid,cl_template,install\n' 
+                             'update_system update,setupsystem,configure')
         fgr = open(group_rights, 'w')
         fgr.write(group_rights_text)
         fgr.close()
@@ -693,7 +694,8 @@ def view_cert(args, certbase, data_path, rights, group_rights):
 
 
 # Sign client request by server certificate
-def sing_req_by_server(id_client_req, cert_path, data_path, auto=False):
+def sing_req_by_server(id_client_req, cert_path, data_path, auto=False,
+                       group_name="all"):
     server_cert = cert_path + '/root.crt'
     server_key = cert_path + '/root.key'
 
@@ -713,9 +715,7 @@ def sing_req_by_server(id_client_req, cert_path, data_path, auto=False):
             print _("Certificate %s now exists") % cl_cert
             return 1
 
-        if auto:
-            group_name = "all"
-        else:
+        if not auto:
             group_name = ""
             while not group_name.split():
                 group_name = "%s" % raw_input(
@@ -1152,26 +1152,33 @@ def parse(full=False):
             '--pid-file', type=str, dest='pidfile',
             help=_('Specify the location of the PID file'))
         parser.add_argument(
-            '-c', '--cert', type=str, dest='Id',
+            '--cert', type=str, dest='Id',
             help=_('operations with certificates (number or "all"). Server not'
                    ' running.'))
         parser.add_argument(
-            '-r', '--show-request', type=str, dest='req_id',
+            '--show-request', type=str, dest='req_id',
             help=_("view client requests (number or \"all\")"))
         parser.add_argument(
             '--sc', '--server-cert', type=str, dest='cert_id',
             help=_('view servers certificates (number or "all"). '
                    'Server not running.'))
         parser.add_argument(
-            '-b', '--bootstrap', type=str, dest='bootstrap_user_name',
-            help=_('bootstrap action'))
+            '-b', '--bootstrap', action='store_true', default=False,
+            dest='bootstrap_user_name', help=_('bootstrap action'))
+        parser.add_argument(
+            '-u', '--create-localuser-cert', type=str, dest='cert_user_name',
+            help=_('create certificate for local user'))
+        parser.add_argument(
+            '--clear-localuser-cert', action='store_true', default=False,
+            dest='clear_user_cert',
+            help=_('remove all local user certificates'))
         parser.add_argument(
             '--remove-certs', action='store_true', default=False,
             dest='remove_certificates',
             help=_('use with option --bootstrap to remove '
                    'all certificates, requests and config files on the server'))
         parser.add_argument(
-            '-d', '--dump', action='store_true', default=False, dest='dump',
+            '--dump', action='store_true', default=False, dest='dump',
             help=_('dump (use with option -c [ID])'))
     parser.add_argument(
         '--db', '--debug', action='store_true', default=False, dest='debug',
@@ -1233,10 +1240,9 @@ def parse(full=False):
     parser.add_argument(
         '--gui-warning', action='store_true', default=False,
         dest='gui_warning', help=_('display warnings at the end'))
-    if full:
-        parser.add_argument(
-            '-f', '--force', action='store_true', default=False,
-            dest='no_questions', help=_('silent during the process'))
+    parser.add_argument(
+        '-f', '--force', action='store_true', default=False,
+        dest='no_questions', help=_('silent during the process'))
     parser.add_argument(
         '-P', action='store_true', default=False,
         dest='stdin_passwd',
